@@ -11,7 +11,6 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-# flake8: noqa
 
 import testtools
 
@@ -222,24 +221,3 @@ class HackingTestCase(base.BaseTestCase):
         self.assertLinePasses(f, "[obj for obj in data if test(obj)]")
         self.assertLinePasses(f, "filter(function, range(0,10))")
         self.assertLinePasses(f, "lambda x, y: x+y")
-
-    def test_line_continuation_no_backslash(self):
-        results = list(checks.check_line_continuation_no_backslash(
-            '', [(1, 'import', (2, 0), (2, 6), 'import \\\n'),
-                 (1, 'os', (3, 4), (3, 6), '    os\n')]))
-        self.assertEqual(1, len(results))
-        self.assertEqual((2, 7), results[0][0])
-
-    def _get_factory_checks(self, factory):
-        check_fns = []
-
-        def _reg(check_fn):
-            self.assertTrue(hasattr(check_fn, '__call__'))
-            self.assertNotIn(check_fn, check_fns)
-            check_fns.append(check_fn)
-
-        factory(_reg)
-        return check_fns
-
-    def test_factory(self):
-        self.assertGreater(len(self._get_factory_checks(checks.factory)), 0)
